django-flavour
==============================


Usage
----------------------

In ``settings.py``, at the very bottom::

    …
    import django_flavour
    django_flavour.settings(locals())




supports only `fam-django` packages at the moment
